You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficcontrol.apache.org by zr...@apache.org on 2023/08/15 23:01:38 UTC

[trafficcontrol] branch master updated: Use GCC 11 to build Apache Traffic Server (#7716)

This is an automated email from the ASF dual-hosted git repository.

zrhoffman pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/trafficcontrol.git


The following commit(s) were added to refs/heads/master by this push:
     new ece83d2e36 Use GCC 11 to build Apache Traffic Server (#7716)
ece83d2e36 is described below

commit ece83d2e36b70516e7f3fd866ba199b480f37c1f
Author: Zach Hoffman <zr...@apache.org>
AuthorDate: Tue Aug 15 17:01:31 2023 -0600

    Use GCC 11 to build Apache Traffic Server (#7716)
    
    * Use GCC 11 to build Apache Traffic Server
    
    * Changelog entry
---
 CHANGELOG.md                                         |  1 +
 cache-config/testing/docker/trafficserver/Dockerfile |  7 +++----
 cache-config/testing/docker/trafficserver/run.sh     |  6 +++---
 traffic_server/_tsb/Dockerfile                       | 12 ++++++------
 4 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/CHANGELOG.md b/CHANGELOG.md
index b4672d5b62..6abdbcb86a 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -72,6 +72,7 @@ The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/).
 - [#7621](https://github.com/apache/trafficcontrol/pull/7621) *Traffic Ops* Use ID token for OAuth authentication, not Access Token
 - [#7694](https://github.com/apache/trafficcontrol/pull/7694) *t3c*, *Traffic Control Health Client* Upgrade to ATS 9.2
 - [#7966](https://github.com/apache/trafficcontrol/pull/7696) *t3c* will no longer clear update flag when config failure occurs and will also give a cache config error msg on exit. 
+- [#7716](https://github.com/apache/trafficcontrol/pull/7716) *Apache Traffic Server* Use GCC 11 for building.
 
 ### Fixed
 - [#4393](https://github.com/apache/trafficcontrol/issues/4393) *Traffic Ops* Fixed the error code and alert structure when TO is queried for a delivery service with no ssl keys.
diff --git a/cache-config/testing/docker/trafficserver/Dockerfile b/cache-config/testing/docker/trafficserver/Dockerfile
index 4b2663811b..731a349f7a 100644
--- a/cache-config/testing/docker/trafficserver/Dockerfile
+++ b/cache-config/testing/docker/trafficserver/Dockerfile
@@ -61,17 +61,16 @@ RUN if [[ ${OS_VERSION%%.*} -ge 8 ]]; then \
 			brotli \
 			brotli-devel \
 			curl \
-			gcc-toolset-9 \
-			gcc-toolset-9-runtime \
+			gcc-toolset-11 \
+			gcc-toolset-11-runtime \
 			geoip \
 			jansson \
 			jansson-devel \
 			libmaxminddb \
 			libmaxminddb-devel \
 			libuuid ); \
-		os_toolset="gcc-toolset-9"; \
 	else \
-		os_pkgs=(devtoolset-9); \
+		os_pkgs=(devtoolset-11); \
 	fi \
 	&& yum install -y \
 		${os_pkgs[*]} \
diff --git a/traffic_server/_tsb/Dockerfile b/traffic_server/_tsb/Dockerfile
index 524b683185..cec03d640a 100644
--- a/traffic_server/_tsb/Dockerfile
+++ b/traffic_server/_tsb/Dockerfile
@@ -54,16 +54,16 @@ RUN if [[ ${RHEL_VERSION%%.*} -ge 8 ]]; then \
 			brotli \
 			brotli-devel \
 			curl \
-			gcc-toolset-9 \
-			gcc-toolset-9-runtime \
+			gcc-toolset-11 \
+			gcc-toolset-11-runtime \
 			jansson \
 			jansson-devel \
 			libmaxminddb \
 			libmaxminddb-devel); \
-		os_toolset="gcc-toolset-9"; \
+		os_toolset="gcc-toolset-11"; \
 	else \
-		os_pkgs=(devtoolset-7); \
-		os_toolset="devtoolset-7"; \
+		os_pkgs=(devtoolset-11); \
+		os_toolset="devtoolset-11"; \
 	fi \
 	&& yum install -y \
 		${os_pkgs[*]} \
@@ -109,7 +109,7 @@ COPY	trafficserver.spec /rpmbuilddir/SPECS/trafficserver.spec
 COPY	traffic_server_jemalloc /rpmbuilddir/SOURCES/traffic_server_jemalloc
 RUN	/usr/sbin/useradd -u 176 -r ats -s /sbin/nologin -d /
 CMD if [[ ${RHEL_VERSION%%.*} -ge 8 ]]; then \
-		os_toolset=gcc-toolset-9; \
+		os_toolset=gcc-toolset-11; \
 		openssl_included='--without_openssl'; \
 	else \
 		os_toolset=devtoolset-7; \
diff --git a/cache-config/testing/docker/trafficserver/run.sh b/cache-config/testing/docker/trafficserver/run.sh
index 8fad9405ba..1e51741740 100755
--- a/cache-config/testing/docker/trafficserver/run.sh
+++ b/cache-config/testing/docker/trafficserver/run.sh
@@ -76,11 +76,11 @@ echo "Building a RPM for ATS version: $ATS_VERSION and OS version: $OS_VERSION"
 # add the 'ats' user
 id ats &>/dev/null || /usr/sbin/useradd -u 176 -r ats -s /sbin/nologin -d /
 
 # setup the environment to use the devtoolset-9 tools.
 if [ "${OS_VERSION%%.*}" -le 7 ]; then 
-  source scl_source enable devtoolset-9
+  source scl_source enable devtoolset-11
 else
-  source scl_source enable gcc-toolset-9
+  source scl_source enable gcc-toolset-11
 fi
 
 cd /root
@@ -76,11 +76,11 @@ echo "Building a RPM for ATS version: $ATS_VERSION and OS version: $OS_VERSION"
 id ats &>/dev/null || /usr/sbin/useradd -u 176 -r ats -s /sbin/nologin -d /
 
-# setup the environment to use the devtoolset-9 tools.
+# setup the environment to use the devtoolset-11 tools.
 if [ "${OS_VERSION%%.*}" -le 7 ]; then 